==> alfresco-repository-23.6.0.28-sources.jar: org/alfresco/repo/tenant/TenantDomainMismatchException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.tenant;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * Exception thrown when an operation that requires 
 *  two things to be in the same tenant domain discovers
 *  that they belong to different ones.
 */
@SuppressWarnings("serial")
public class TenantDomainMismatchException extends AlfrescoRuntimeException
{
    private String tenantA;
    private String tenantB;
    
    public TenantDomainMismatchException(String tenantA, String tenantB)
    {
        super(
                "domain mismatch: expected = " + renderTenent(tenantA) + 
                ", actual = " + renderTenent(tenantB)
        );
                
        this.tenantA = tenantA;
        this.tenantB = tenantB;
    }
    private static String renderTenent(String tenant)
    {
        if(tenant == null)
            return "<none>";
        return tenant;
    }
    
    public String getTenantA()
    {
        return tenantA;
    }
    public String getTenantB()
    {
        return tenantB;
    }
}

==> alfresco-repository-25.3.0.55-sources.jar: org/alfresco/repo/tenant/TenantDomainMismatchException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.tenant;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * Exception thrown when an operation that requires two things to be in the same tenant domain discovers that they belong to different ones.
 */
@SuppressWarnings("serial")
public class TenantDomainMismatchException extends AlfrescoRuntimeException
{
    private String tenantA;
    private String tenantB;

    public TenantDomainMismatchException(String tenantA, String tenantB)
    {
        super(
                "domain mismatch: expected = " + renderTenent(tenantA) +
                        ", actual = " + renderTenent(tenantB));

        this.tenantA = tenantA;
        this.tenantB = tenantB;
    }

    private static String renderTenent(String tenant)
    {
        if (tenant == null)
            return "<none>";
        return tenant;
    }

    public String getTenantA()
    {
        return tenantA;
    }

    public String getTenantB()
    {
        return tenantB;
    }
}
